"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class Container {
    constructor(providers = [], services = {}) {
        this.providers = providers;
        this.services = services;
        this.injectProperties = {};
    }
    register(...serviceClasses) {
        this.providers.push(...serviceClasses);
        serviceClasses.forEach((serviceClass) => {
            let service = serviceClass;
            if (service instanceof Function) {
                service = new serviceClass();
            }
            this.add(service);
        });
    }
    registerByName(name, serviceClass) {
        let service = serviceClass;
        if (service instanceof Function) {
            service = new serviceClass();
        }
        this.addByName(name, service);
    }
    add(service) {
        return this.addByName(service.constructor.name, service);
    }
    addByName(name, service) {
        this.services[name] = service;
        this.services[name.toLowerCase()] = service;
        this.inject(service, name);
        return this.get(name);
    }
    get(name) {
        return this.services[name];
    }
    getByType(c) {
        return this.get(c.name.toLowerCase());
    }
    addInjectProperty(target, key) {
        if (target) {
            this.getInjectProperty(key.toLowerCase()).push({ target, key });
        }
    }
    inject(service, name = service.constructor.name) {
        this.getInjectProperty(name.toLowerCase()).forEach((property) => {
            property.target[property.key] = service;
        });
    }
    getInjectProperty(key) {
        if (!this.injectProperties[key]) {
            this.injectProperties[key] = [];
        }
        return this.injectProperties[key];
    }
}
exports.Container = Container;
exports.default = Container;
//# sourceMappingURL=Container.js.map