"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Container_1 = require("../src/Container");
class Greeter {
    sayHello(name) {
        return `Hello ${name || 'World'}!`;
    }
}
describe('Given an IoC container it', () => {
    let container;
    beforeEach(() => {
        container = new Container_1.Container();
        const services = Object.keys(container.getAll());
        expect(services.length).toEqual(0);
    });
    it('Should be able to register a class', () => {
        container.register(Greeter);
        const services = Object.keys(container.getAll());
        expect(services.indexOf('greeter')).toBeGreaterThanOrEqual(0);
        expect(services.length).toEqual(2);
    });
    it('Should be able to register a class with custom name', () => {
        container.registerByName('my-greeter', Greeter);
        const services = Object.keys(container.getAll());
        expect(services.indexOf('greeter')).toBeGreaterThanOrEqual(-1);
        expect(services.indexOf('my-greeter')).toBeGreaterThanOrEqual(0);
        expect(services.length).toEqual(1);
    });
    it('Should be able to register an object with custom name', () => {
        container.registerByName('my-greeter', new Greeter());
        const services = Object.keys(container.getAll());
        expect(services.indexOf('greeter')).toBeGreaterThanOrEqual(-1);
        expect(services.indexOf('my-greeter')).toBeGreaterThanOrEqual(0);
        expect(services.length).toEqual(1);
    });
    it('Should be able to get an object by name', () => {
        container.register(new Greeter());
        const services = Object.keys(container.getAll());
        expect(services.indexOf('greeter')).toBeGreaterThanOrEqual(0);
        expect(services.length).toEqual(2);
    });
    it('Should be able to get an object by custom name', () => {
        container.registerByName('my-greeter', new Greeter());
        const greeter = container.get('my-greeter');
        expect(greeter).toBeDefined();
        expect(greeter.sayHello).toBeDefined();
    });
    it('Should be able to get an object by type', () => {
        container.register(new Greeter());
        const greeter = container.getByType(Greeter);
        expect(greeter).toBeDefined();
        expect(greeter.sayHello).toBeDefined();
    });
    it('Should be able to add an inject property', () => {
        container.registerByName('greeter', new Greeter());
        const target = { greeter: undefined };
        container.addInjectProperty(target, 'greeter');
        expect(target.greeter).toBeDefined();
        expect(target.greeter.sayHello).toBeDefined();
    });
    it('Should be able to add an inject property before service is registered', () => {
        const target = { greeter: undefined };
        container.addInjectProperty(target, 'greeter');
        expect(target.greeter).toBeUndefined();
        container.registerByName('greeter', new Greeter());
        expect(target.greeter).toBeDefined();
        expect(target.greeter.sayHello).toBeDefined();
    });
});
//# sourceMappingURL=Container-spec.js.map