"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const SimpleCI_1 = require("../src/SimpleCI");
class Dismisser {
    sayBye(name) {
        return `Good bye ${name || 'World'}!`;
    }
}
describe('Given the SimpleCI interface it', () => {
    beforeEach(() => {
        SimpleCI_1.SimpleCI.container = null;
    });
    it('Should be able to register a class', () => {
        SimpleCI_1.SimpleCI.register(Dismisser);
        const services = Object.keys(SimpleCI_1.SimpleCI.getAll());
        expect(services.indexOf('dismisser')).toBeGreaterThanOrEqual(0);
        expect(services.length).toEqual(2);
    });
    it('Should be able to register an object with custom name', () => {
        SimpleCI_1.SimpleCI.registerByName('my-dismisser', new Dismisser());
        const services = Object.keys(SimpleCI_1.SimpleCI.getAll());
        expect(services.indexOf('dismisser')).toBeGreaterThanOrEqual(-1);
        expect(services.indexOf('my-dismisser')).toBeGreaterThanOrEqual(0);
        expect(services.length).toEqual(1);
    });
    it('Should be able to get an object by name', () => {
        SimpleCI_1.SimpleCI.register(new Dismisser());
        const services = Object.keys(SimpleCI_1.SimpleCI.getAll());
        expect(services.indexOf('dismisser')).toBeGreaterThanOrEqual(0);
        expect(services.length).toEqual(2);
    });
    it('Should be able to get an object by custom name', () => {
        SimpleCI_1.SimpleCI.registerByName('my-dismisser', new Dismisser());
        const dismisser = SimpleCI_1.SimpleCI.get('my-dismisser');
        expect(dismisser).toBeDefined();
        expect(dismisser.sayBye).toBeDefined();
    });
    it('Should be able to get an object by type', () => {
        SimpleCI_1.SimpleCI.register(new Dismisser());
        const dismisser = SimpleCI_1.SimpleCI.getByType(Dismisser);
        expect(dismisser).toBeDefined();
        expect(dismisser.sayBye).toBeDefined();
    });
    it('Should be able to add an inject property', () => {
        SimpleCI_1.SimpleCI.registerByName('dismisser', new Dismisser());
        const target = { dismisser: undefined };
        SimpleCI_1.SimpleCI.addInjectProperty(target, 'dismisser');
        expect(target.dismisser).toBeDefined();
        expect(target.dismisser.sayBye).toBeDefined();
    });
});
//# sourceMappingURL=SimpleCI-spec.js.map